import { request, upload } from "@/lib/service"
import { baseUrl } from '@/config'

/**
 * @desc 四级联动-省市区街道
 * @param { Number } code // city code => default 1   
 */
export function queryCity(code = '1') {
	return request({
		url: 'zsxcx/areaLinkXcx.htm',
		method: 'post',
		data: {
			code
		}
	})
}

/**
 * @desc 浏览历史接口
 * @param { String } last_time 上一次查询时间（yyyy-MM-dd）
 */
export function historyList(last_time) {
	return request({
		url: 'zsxcx/browse.htm',
		method: 'post',
		data: {last_time},
		needMask: true
	})
}


/**
 * @desc 删除一条浏览历史接口
 * @param {  Number } bro_id 浏览历史ID
 * @param {  Number } goods_id 商品ID
 */
export function delHistory({bro_id, goods_id}) {
	return request({
		url: 'zsxcx/delBrowse.htm',
		method: 'post',
		data: {
			bro_id,
			goods_id
		},
		needMask: true
	})
}

/**
 * @desc 清空全部历史
 */
export function clearAllHistory() {
	return request({
		url: 'zsxcx/delBrowseAll.htm',
		method: 'post',
		needMask: true
	})
}

/**
 * @desc 获取店铺信息
 */
export function getStoreInfo() {
	return request({
		url: 'zsxcx/shopDetail.htm',
		method: 'post'
	})
}

export function pay({order_sn, openid}) {
	return request({
		url: 'zsxcx/orderWxPay.htm',
		method: 'post',
		data: {
			order_sn, openid
		},
		needMask: true
	})
}


/**
 * @param {Object} formData
 * @param { file } tempFile
 * formData.type 上传文件类型：1图片 2视频
 */
export function upLoadFile(tempFile, formData) {
	return upload({
		url: 'zsxcx/uploadCommentsFiles.htm',
		tempFile,
		formData
	})
}