import { pay } from '@/apis/common.js'
import store from '@/store/index.js'
import Toast from '@/lib/toast/index.js'
import { isFunction } from "@/utils/types.js"

/**
 * @desc 生成订单(后端调用统一下单)，返回拉起支付的参数
 * @param { String } order_sn 订单编号 (此订单编号是我们后台生成的订单编号)
 * @param { Function } successCb
 * @param { Function } failCb
 */
export default async function createOrder({ order_sn, successCb, failCb
}) {
	try{
		const openid = store.state.user.openid
		if(!openid || !order_sn) return
		const { status, data } = await pay({order_sn, openid })
		if(status) {
			return wxPay({
				params: data,
				successCb,
				failCb
			})
		}
	}catch(e){
		console.log(e)
		Toast({title: e.msg || '支付失败'})
	} 
}



/**
 * @微信支付
 * @param { Functiom } successCb 成功回调函数
 * @param { Functiom } failCb 失败回调函数
 * @param { Object } params 支付参数
 * 
 timeStamp: '',
 nonceStr: '',
 package: '',
 signType: 'RSA',
 paySign: '',
 */
function wxPay({
	params, 
	successCb, 
	failCb
}) {
	wx.requestPayment({
		// provider: 'wxpay',
		...Object.assign(params, {
			signType: 'RSA'
		}),
		success: res => {
			// do 
			console.log(res)
			successCb && isFunction(successCb) && successCb()
		},
		fail: err => {
			console.log(err)
			failCb && isFunction(failCb) && failCb()
		}
	})
	
}